@@ -9,6 +9,7 @@
 
 package org.gnu.gnome;
 
+import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.Button;
 import org.gnu.glib.Handle;
@@ -21,6 +22,21 @@ import org.gnu.glib.Handle;
  */
 public class HRef extends Button {
 
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
+    public static HRef getHRef(Handle handle) {
+        if (handle == null) {
+            return null;
+        }
+
+        HRef href = (HRef) GObject.getGObjectFromHandle(handle);
+        if (href == null) {
+            href = new HRef(handle);
+        }
+        return href;
+    }
+
     /**
      * Creates a new HRef with the given URL and label.
      * 
